@@ -54,6 +54,7 @@ struct _PersonalPhotoFramePrivate
 	gboolean singleMode;
 	gchar *singleFilename;
 	gchar *slideshowDirname;
+	gchar *slideshowFilename;
 	gint slideshowNum;
 	gint slideshowDuration;
 	gboolean slideshowRandom;
@@ -224,7 +225,7 @@ void personal_photo_frame_button_release (GtkWidget *widget, GdkEventButton *eve
 		if (gdk_event_get_coords (event, &x_coord, &y_coord)) {
 			if (y_coord > 310.0 - 48.0) {
 				if (x_coord > 310.0 - 48.0) {
-					self->priv->slideshowNum++;
+					//self->priv->slideshowNum++;
 					personal_photo_frame_update_content (self);
 					personal_photo_frame_remove_timers (self);
 					personal_photo_frame_add_timers (self);
@@ -233,7 +234,23 @@ void personal_photo_frame_button_release (GtkWidget *widget, GdkEventButton *eve
 					personal_photo_frame_update_content (self);
 					personal_photo_frame_remove_timers (self);
 					personal_photo_frame_add_timers (self);
+				} else {
+					DBusConnection *conn = dbus_bus_get(DBUS_BUS_SESSION, NULL);
+					if (self->priv->singleMode) {
+						hildon_mime_open_file (conn, self->priv->singleFilename);
+					} else {
+						hildon_mime_open_file (conn, self->priv->slideshowFilename);
+					}
+					dbus_connection_unref(conn);
 				}
+			} else {
+				DBusConnection *conn = dbus_bus_get(DBUS_BUS_SESSION, NULL);
+				if (self->priv->singleMode) {
+					hildon_mime_open_file (conn, self->priv->singleFilename);
+				} else {
+					hildon_mime_open_file (conn, self->priv->slideshowFilename);
+				}
+				dbus_connection_unref(conn);
 			}
 		}
 	}
@@ -310,9 +327,9 @@ void personal_photo_frame_update_content (PersonalPhotoFrame *self)
 					gdk_pixbuf_fill (self->priv->image, 0x00000000);
 					gtk_widget_queue_draw (self);
 				} else {
-					gchar *fullName = g_strconcat (self->priv->slideshowDirname, "/", filename, NULL);
+					self->priv->slideshowFilename = g_strconcat (self->priv->slideshowDirname, "/", filename, NULL);
 
-					GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_scale (fullName, 305, 305, TRUE, NULL);
+					GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_scale (self->priv->slideshowFilename, 305, 305, TRUE, NULL);
 					if (pixbuf) {
 						g_object_unref (self->priv->image);
 						self->priv->image = gdk_pixbuf_copy (pixbuf);
@@ -322,7 +339,6 @@ void personal_photo_frame_update_content (PersonalPhotoFrame *self)
 						gtk_widget_queue_draw (self);
 					}
 					g_free (filename);
-					g_free (fullName);
 				}
 			}
 			g_dir_close (dir);
@@ -568,7 +584,11 @@ static gboolean personal_photo_frame_expose_event (GtkWidget *widget, GdkEventEx
 	gint pixbufHeight=gdk_pixbuf_get_height(self->priv->image);
 	gdk_cairo_set_source_pixbuf (cr, self->priv->image, 5 + ((305-pixbufWidth)/2), 5 + ((305-pixbufHeight)/2));
 	cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
-	cairo_paint (cr);
+	if (!self->priv->isPressed) {
+		cairo_paint (cr);
+	} else {
+		cairo_paint_with_alpha (cr, 0.75);
+	}
 	
 	cairo_destroy(cr);
 	
